"""Mlqa group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

MLQA_TASKS = {
    "mlqa": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_ar_ar": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_ar_de": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_ar_vi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_ar_zh": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_ar_en": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_ar_es": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_ar_hi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_de_ar": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_de_de": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_de_vi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_de_zh": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_de_en": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_de_es": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_de_hi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_vi_ar": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_vi_de": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_vi_vi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_vi_zh": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_vi_en": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_vi_es": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_vi_hi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_zh_ar": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_zh_de": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_zh_vi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_zh_zh": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_zh_en": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_zh_es": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_zh_hi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_en_ar": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_en_de": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_en_vi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_en_zh": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_en_en": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_en_es": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_en_hi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_es_ar": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_es_de": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_es_vi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_es_zh": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_es_en": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_es_es": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_es_hi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_hi_ar": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_hi_de": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_hi_vi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_hi_zh": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_hi_en": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_hi_es": f"{BASE_IMPORT}mlqa:MlqaExtractor",
    "mlqa_hi_hi": f"{BASE_IMPORT}mlqa:MlqaExtractor",
}
